@@ -21,19 +21,20 @@ def _get_aws_instance_metadata(url, timeout=2):
         token_url = "http://169.254.169.254/latest/api/token"
         token_headers = {"X-aws-ec2-metadata-token-ttl-seconds": "21600"}
         token_response = requests.put(token_url, headers=token_headers, timeout=timeout)
-        
+
         if token_response.status_code == 200:
             token = token_response.text
             headers = {"X-aws-ec2-metadata-token": token}
         else:
             headers = None
-        
+
         response = requests.get(url, headers=headers, timeout=timeout)
         response.raise_for_status()
         return response.text
     except requests.RequestException:
         return None
 
+
 def _get_gcp_instance_metadata(url, timeout=2):
     try:
         headers = {"Metadata-Flavor": "Google"}
@@ -43,32 +44,40 @@ def _get_gcp_instance_metadata(url, timeout=2):
     except requests.RequestException:
         return None
 
+
 def _determine_maitai_host():
     if maitai_host := os.environ.get("MAITAI_HOST"):
-        return maitai_host.rstrip('/')
-    
-    if _get_aws_instance_metadata("http://169.254.169.254/latest/meta-data/placement/region") == "us-west-2":
+        return maitai_host.rstrip("/")
+
+    if (
+        _get_aws_instance_metadata(
+            "http://169.254.169.254/latest/meta-data/placement/region"
+        )
+        == "us-west-2"
+    ):
         return "https://api.aws.us-west-2.trymaitai.ai"
-    
-    gcp_zone = _get_gcp_instance_metadata("http://metadata.google.internal/computeMetadata/v1/instance/zone")
+
+    gcp_zone = _get_gcp_instance_metadata(
+        "http://metadata.google.internal/computeMetadata/v1/instance/zone"
+    )
     if gcp_zone:
         if "us-west1" in gcp_zone:
             return "https://api.gcp.us-west1.trymaitai.ai"
         elif "us-central1" in gcp_zone:
             return "https://api.gcp.us-central1.trymaitai.ai"
-    
+
     return "https://api.trymaitai.ai"
 
+
 class Config:
     maitai_host = _determine_maitai_host()
-    maitai_ws = os.environ.get("MAITAI_WS", 'wss://09hidyy627.execute-api.us-west-2.amazonaws.com/production')
+    maitai_ws = os.environ.get(
+        "MAITAI_WS", "wss://09hidyy627.execute-api.us-west-2.amazonaws.com/production"
+    )
     config_dir = os.path.expanduser(os.environ.get("MAITAI_CONFIG_DIR", "~/.maitai"))
 
     def __init__(self):
-        retry_strategy = Retry(
-            total=3,
-            backoff_factor=1
-        )
+        retry_strategy = Retry(total=3, backoff_factor=1)
         adapter = HTTPAdapter(max_retries=retry_strategy)
 
         self._session = requests.Session()
@@ -86,17 +95,24 @@ class Config:
             openai_api_key=Key(id=-1, key_value=os.environ.get("OPENAI_API_KEY")),
             groq_api_key=Key(id=-1, key_value=os.environ.get("GROQ_API_KEY")),
             anthropic_api_key=Key(id=-1, key_value=os.environ.get("ANTHROPIC_API_KEY")),
+            cerebras_api_key=Key(id=-1, key_value=os.environ.get("CEREBRAS_API_KEY")),
         )
+        self.refresh_timer = None
+        self.refresh_interval = 300  # 5 minutes in seconds
 
     @property
     def api_key(self):
         if self._api_key is None:
             if self.initialized:
-                raise ValueError("Maitai API Key has not been set. Either pass it directly into the client, or by setting the environment variable MAITAI_API_KEY.")
+                raise ValueError(
+                    "Maitai API Key has not been set. Either pass it directly into the client, or by setting the environment variable MAITAI_API_KEY."
+                )
             else:
                 api_key = os.environ.get("MAITAI_API_KEY")
                 if not api_key:
-                    raise ValueError("Maitai API Key has not been set. Either pass it directly into the client, or by setting the environment variable MAITAI_API_KEY.")
+                    raise ValueError(
+                        "Maitai API Key has not been set. Either pass it directly into the client, or by setting the environment variable MAITAI_API_KEY."
+                    )
                 self.initialize(api_key=api_key)
         return self._api_key
 
@@ -113,6 +129,7 @@ class Config:
             self._initialize_company()
             self.refresh_applications()
             self._initialize_websocket()
+            self._start_refresh_timer()
         except Exception as e:
             try:
                 self._load_config_from_file()
@@ -120,23 +137,46 @@ class Config:
                 raise e
             self.initialized = False
             if retry < 5:
-                t = threading.Timer(interval=2 ** retry, function=self.initialize, args=(api_key, retry))
+                t = threading.Timer(
+                    interval=2**retry, function=self.initialize, args=(api_key, retry)
+                )
                 t.daemon = True
                 t.start()
 
+    def _start_refresh_timer(self):
+        if self.refresh_timer:
+            self.refresh_timer.cancel()
+        self.refresh_timer = threading.Timer(
+            self.refresh_interval, self._refresh_and_reschedule
+        )
+        self.refresh_timer.daemon = True
+        self.refresh_timer.start()
+
+    def _refresh_and_reschedule(self):
+        try:
+            self.refresh_applications()
+        except Exception as e:
+            pass
+        finally:
+            self._start_refresh_timer()
+
     def get_application(self, application_ref_name: str) -> Application:
         return self._applications.get(application_ref_name)
 
-    def get_application_action_config(self, application_ref_name: str, action_type: str) -> ActionConfig:
-        return self._application_action_configs.get(application_ref_name, {}).get(action_type, config_service.get_default_config())
+    def get_application_action_config(
+        self, application_ref_name: str, action_type: str
+    ) -> ActionConfig:
+        return self._application_action_configs.get(application_ref_name, {}).get(
+            action_type, config_service.get_default_config()
+        )
 
     def _initialize_company(self):
         host = self.maitai_host
-        url = f'{host}/company/'
+        url = f"{host}/company/"
         headers = {
-            'Content-Type': 'application/json',
-            'x-api-key': self.api_key,
-            'x-client-version': version,
+            "Content-Type": "application/json",
+            "x-api-key": self.api_key,
+            "x-client-version": version,
         }
 
         response = self._session.get(url, headers=headers, timeout=15)
@@ -148,27 +188,36 @@ class Config:
 
     def refresh_applications(self):
         host = self.maitai_host
-        url = f'{host}/application/'
+        url = f"{host}/application/"
         headers = {
-            'Content-Type': 'application/json',
-            'x-api-key': self.api_key,
-            'x-client-version': version,
+            "Content-Type": "application/json",
+            "x-api-key": self.api_key,
+            "x-client-version": version,
         }
 
         response = self._session.get(url, headers=headers, timeout=15)
         self._session.close()
         if response.status_code != 200:
             raise Exception(f"Failed to initialize Maitai client: {response.text}")
-        applications = [Application().from_dict(app_json) for app_json in response.json()]
+        applications = [
+            Application().from_dict(app_json) for app_json in response.json()
+        ]
         return self.store_application_metadata(applications)
 
     def store_application_metadata(self, applications: List[Application]):
         for application in applications:
             self._applications[application.application_ref_name] = application
             for action_type in application.action_types:
-                if application.application_ref_name not in self._application_action_configs:
-                    self._application_action_configs[application.application_ref_name] = {}
-                self._application_action_configs[application.application_ref_name][action_type.action_type] = action_type.meta
+                if (
+                    application.application_ref_name
+                    not in self._application_action_configs
+                ):
+                    self._application_action_configs[
+                        application.application_ref_name
+                    ] = {}
+                self._application_action_configs[application.application_ref_name][
+                    action_type.action_type
+                ] = action_type.meta
         self._dump_application_metadata()
 
     def _dump_application_metadata(self):
@@ -179,7 +228,9 @@ class Config:
             for ref_name, intent_map in self._application_action_configs.items():
                 config_object[ref_name] = {}
                 for intent_name, intent_config in intent_map.items():
-                    config_object[ref_name][intent_name] = intent_config.to_pydict(casing=Casing.SNAKE, include_default_values=False)
+                    config_object[ref_name][intent_name] = intent_config.to_pydict(
+                        casing=Casing.SNAKE, include_default_values=False
+                    )
             f.write(json.dumps(config_object, indent=2))
 
     def _load_config_from_file(self):
@@ -190,10 +241,14 @@ class Config:
                 if ref_name not in self._application_action_configs:
                     self._application_action_configs[ref_name] = {}
                 for intent_name, intent_config in intent_map.items():
-                    self._application_action_configs[ref_name][intent_name] = ActionConfig().from_pydict(intent_config)
+                    self._application_action_configs[ref_name][
+                        intent_name
+                    ] = ActionConfig().from_pydict(intent_config)
 
     def _initialize_websocket(self):
-        self.config_listener_thread = ConfigListenerThread(self, self.maitai_ws, "APPLICATION_CONFIG_CHANGE", self._company_id)
+        self.config_listener_thread = ConfigListenerThread(
+            self, self.maitai_ws, "APPLICATION_CONFIG_CHANGE", self._company_id
+        )
         self.config_listener_thread.daemon = True
         self.config_listener_thread.start()
 
@@ -201,6 +256,9 @@ class Config:
         if self.config_listener_thread:
             self.config_listener_thread.terminate()
             self.config_listener_thread = None
+        if self.refresh_timer:
+            self.refresh_timer.cancel()
+            self.refresh_timer = None
 
 
 config = Config()
