@@ -213,6 +213,12 @@ def get_chat_completion_params(
                             type=property_value.get("type"),
                             description=property_value.get("description"),
                         )
+                        if property_value.get("items"):
+                            properties[
+                                property_name
+                            ].items = chat_types.FunctionParameters().from_dict(
+                                property_value.get("items")
+                            )
                     else:
                         properties[property_name] = property_value
                 params.tools.append(
